package org.sample.calculator.web;

import java.io.IOException;
import java.io.PrintWriter;

import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.sample.calculator.addition.service.Addition;
import org.sample.calculator.multiplication.service.Multiplication;

/**
 * Servlet implementation class CalculatorServlet
 */
@WebServlet("/CalculatorServlet")
public class CalculatorServlet extends HttpServlet {
	private static final long serialVersionUID = 1L;
       
    /**
     * @see HttpServlet#HttpServlet()
     */
    public CalculatorServlet() {
        super();
    }

	/**
	 * @see HttpServlet#doGet(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		doPost(request, response);
	}

	/**
	 * @see HttpServlet#doPost(HttpServletRequest request, HttpServletResponse response)
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		String param1 = request.getParameter("num1");
		String param2 = request.getParameter("num2");
		String op = request.getParameter("operation");
		Integer a = 0;
		Integer b = 0;
		Integer result = 0;
		int operation = (op == null || op.isEmpty()) ? 1 : Integer.parseInt(op);
		
		PrintWriter writer = null;
		try {
			writer = response.getWriter();
		} catch (IOException e) {
			e.printStackTrace();
		}

		if (writer == null)
			return;

		try {
			a = (param1 == null || param1.isEmpty()) ? 0 : Integer.parseInt(param1);
			b = (param2 == null || param2.isEmpty()) ? 0 : Integer.parseInt(param2);
		} catch(NumberFormatException nfe) {
			postResults(writer, param1, param2, operation, result.toString(), "Unsupported operation, please try integer parameters");
			return;
		}

		try {
			InitialContext context = new InitialContext();

			switch (operation) {
			case 1:
				Addition additionService = (Addition)context.lookup("osgi:service/"+Addition.class.getName());
				result = additionService.add(a, b);
				break;
			case 2:
				Multiplication multiplicationService = (Multiplication)context.lookup("osgi:service/"+Multiplication.class.getName());
				result = multiplicationService.multiply(a, b);
				break;
			}

			postResults(writer, a.toString(), b.toString(), operation, result.toString(), "");
		} catch (NamingException e1) {
			e1.printStackTrace();
		}
	}

	private void postResults(PrintWriter writer, String a, String b, int operation, String result, String errorMessage) {
		writer.println("<!DOCTYPE HTML>");
		writer.println("<html>");
		writer.println("<title>calculator</title>");
		writer.println("<meta http-equiv=\"Content-Type\" content=\"text/html; charset=ISO-8859-1\">");
		writer.println("</head>");
		writer.println("<body>");
		writer.println("<h1>IBM Rational Application Developer for WebSphere Software</h1>");
		writer.println("<h1>Sample Calculator!</h1>");
		if(errorMessage != null && errorMessage.length() > 0) {
			writer.println("<h1>"+errorMessage+"!</h1>");
		}
		writer.println("<form action=\"/org.sample.calculator.web/CalculatorServlet\" method=\"post\">");
		writer.println("<input type=\"text\" name=\"num1\" size=\"5\" value=\""+a+"\">");
		writer.println("<select name=\"operation\">");
		String opc1Select = (operation == 1) ? "selected=\"selected\"":"";
		writer.println("<option value=\"1\""+opc1Select+">+</option>");
		String opc3Select = (operation == 2) ? "selected=\"selected\"":"";
		writer.println("<option value=\"2\""+opc3Select+">x</option>");
		writer.println("</select>");
		writer.println("<input type=\"text\" name=\"num2\" size=\"5\" value=\""+b+"\">");
		writer.println("<input type=\"submit\" name=\"calculate\" value=\"=\" value=\"calculate\">");
		writer.println("<label>"+result+"</label>");
		writer.println("</form>");
		writer.println("</body>");
	}

}
